Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var Cookie = require('js-cookie');
var reactRouterDom = require('react-router-dom');

/**
 * Initialized Auth Context
 */
var Auth = React__default.createContext(null);
var AuthContextProvider = Auth.Provider;
var AuthContextConsumer = Auth.Consumer;
var AuthContext = Auth;

var AuthProvider = function (_a) {
    var cookieName = _a.cookieName, children = _a.children;
    var initState = Cookie.get(cookieName) ? Cookie.get(cookieName) : null;
    var _b = React.useState(initState), authToken = _b[0], setAuthToken = _b[1];
    React.useEffect(function () {
        if (authToken === undefined || authToken === null) {
            Cookie.remove(cookieName);
        }
        else {
            Cookie.set(cookieName, authToken);
        }
    }, [cookieName, authToken]);
    return (React__default.createElement(React__default.Fragment, null,
        React__default.createElement(AuthContextProvider, { value: { authToken: authToken, setAuthToken: setAuthToken } }, children)));
};
AuthProvider.defaultProps = {
    cookieName: "_user"
};

/**
 * Checks if the USER is logged in or not
 * @returns {{auth: boolean, authToken: string}} AuthObject
 */
var isAuth = function () {
    var value = React.useContext(AuthContext);
    if (value === null || value === void 0 ? void 0 : value.authToken) {
        return { auth: true, authToken: value.authToken };
    }
    else {
        return { auth: false, authToken: null };
    }
};

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

/**
 *
 * @param component
 * @param loginPath
 * @param path
 * @param rest
 * @constructor
 */
var PrivateRoute = function (_a) {
    var component = _a.component, loginPath = _a.loginPath, path = _a.path, rest = __rest(_a, ["component", "loginPath", "path"]);
    var auth = isAuth().auth;
    if (auth) {
        return React__default.createElement(reactRouterDom.Route, __assign({ component: component, path: path }, rest));
    }
    else {
        return React__default.createElement(reactRouterDom.Redirect, { to: loginPath });
    }
};

var loginAuth = function (jwtToken) {
    try {
        var c = React.useContext(AuthContext);
        c === null || c === void 0 ? void 0 : c.setAuthToken(jwtToken);
        return true;
    }
    catch (e) {
        return false;
    }
};
var logoutAuth = function () {
    try {
        var c = React.useContext(AuthContext);
        if (c === null || c === void 0 ? void 0 : c.authToken) {
            c.setAuthToken(null);
            return true;
        }
        else {
            return false;
        }
    }
    catch (e) {
        return false;
    }
};

var authHeader = function () {
    var c = React.useContext(AuthContext);
    if (c === null || c === void 0 ? void 0 : c.authToken) {
        return { Authorization: "Bearer " + c.authToken };
    }
    else {
        return { Authorization: null };
    }
};

exports.AuthProvider = AuthProvider;
exports.PrivateRoute = PrivateRoute;
exports.authHeader = authHeader;
exports.isAuth = isAuth;
exports.loginAuth = loginAuth;
exports.logoutAuth = logoutAuth;
//# sourceMappingURL=index.js.map
